@@ -5,7 +5,7 @@ use warnings;
 
 use base qw(Text::CSV);
 
-our $VERSION = '0.299_001';
+our $VERSION = '0.399_001';
 
 sub new {
     my ($self, $hash) = @_;
@@ -74,13 +74,13 @@ but does not permit control characters.
 
 =head1 Incompatible Changes
 
-=head2 always_quote (v0.300)
+=head2 Option always_quote=>1 (v0.300)
 
 Before v0.300, the module behaviour defaulted to 
 C<< always_quote => 1 >> in Text::CSV.  
 This behaviour was only needed in tests.
 
-To recreat the old behaviour use
+To recreate the old behaviour:
 
     $csv = Text::CSV::Unicode->new( { always_quote => 1 } );
 
@@ -89,7 +89,7 @@ To recreat the old behaviour use
 The option C<< binary => 1 >> does not require this module.
 
 This code issues a 'deprecated' warning and creates a 
-Text::CSV object.
+Text::CSV object:
 
     $csv = Text::CSV::Unicode->new( { binary => 1 } );
 
@@ -120,7 +120,6 @@ C<< binary => 0 >> allows the same ASCII input as Text::CSV.
 C<< binary => 1 >> allows for all Unicode
 characters in the input (including \r and \n):
 the same functionality as C<< Text::CSV->new( { binary => 1 } >>.
-This option is deprecated.
 
 =item combine
 
